{% extends base_template_path %}
{% load powercrud %}
{% load partials %}

{% block content %}
    {% partial pcrud_content %}
{% endblock %}

{% partialdef pcrud_content %}
    <div class="m-2 p-2">
        <h1 class="title is-4">{{ object }}</h1>
        {% object_detail object view %}
    </div>
{% endpartialdef pcrud_content %}
