{% extends base_template_path %}
{% load powercrud %}
{% load partials %}

{% block content %}
    {% partial pcrud_content %}

{% endblock %}

{% partialdef pcrud_content %}
    <div class="is-flex is-flex-direction-column m-2 p-2">
        <div class="box">
            <p class="">Are you sure you want to delete the following {{ object_verbose_name }}?</p>
            <h1 class="title is-5 mb-2">{{ object }}</h1>
        
            <form method="POST" action="{{ delete_view_url }}"
                {% if use_htmx and original_target %}
                hx-post="{{ delete_view_url }}"
                hx-target="{{ original_target }}"
                hx-push-url="true"
                {% endif %}
            >
                {% csrf_token %}
                {{ form }}
                <button type="submit" class="btn btn-danger">Delete</button>
            </form>
        </div>
    </div>
{% endpartialdef pcrud_content %}
